@@ -19,6 +19,12 @@
  *
  */
 
+/* Get i18n. */
+#include <gettext.h>
+#define _(String) dgettext (PACKAGE, String)
+#define gettext_noop(String) String
+#define N_(String) gettext_noop (String)
+
 #include "k5internal.h"
 
 struct gss_status_codes
