@@ -41,8 +41,8 @@ typedef struct _gss_krb5_ctx_struct
   Shishi_key *key;
   gss_name_t peerptr;
   int acceptor;
-  int acceptseqnr;
-  int initseqnr;
+  uint32_t acceptseqnr;
+  uint32_t initseqnr;
   OM_uint32 flags;
   int reqdone;
   int repdone;
